@@ -38,13 +38,15 @@ class BaseStorageBackend(metaclass=abc.ABCMeta):
 
         This method has no effect if the file is already closed.
         """
+        if handler.is_dirty():
+            await self.async_push(handler.fd.name, handler.path)
         await handler.fd.__aexit__()
 
-    async def async_download(self, path, dst):
+    async def async_download(self, path, dst, decryptor):
         """Downloads file from `path` to `dst` on the local filesystem."""
         raise NotImplementedError("Subclasses must override this method.")
 
-    async def async_push(self, src, path):
+    async def async_push(self, src, path, encryptor=None):
         """Copies local absolute path `src` to remote `path`."""
         raise NotImplementedError("Subclasses must override this method.")
 
@@ -58,14 +60,14 @@ class BaseStorageBackend(metaclass=abc.ABCMeta):
         """Open the given `path` in the given `mode`."""
         return self.async_descriptor_class(self, path, mode, *args, **kwargs)
 
-    async def async_pull(self, path, dst=None):
+    async def async_pull(self, path, dst=None, decryptor=None):
         """Pulls a file from the given `path` in the storage backend to local
         filepath `dst`. If `dst` is ``None``, then a temporary filepath is
         generated.
         """
         if dst is None:
             _, dst = tempfile.mkstemp()
-        return await self.async_download(path, dst)
+        return await self.async_download(path, dst, decryptor)
 
     def close(self, handler):
         """Flush and close the IO object.
@@ -74,14 +76,10 @@ class BaseStorageBackend(metaclass=abc.ABCMeta):
         """
         raise NotImplementedError("Subclasses must override this method.")
 
-    def download(self, path, dst):
+    def download(self, path, dst, decryptor):
         """Downloads file from `path` to `dst` on the local filesystem."""
         raise NotImplementedError("Subclasses must override this method.")
 
-    def push(self, src, path):
-        """Copies local absolute path `src` to remote `path`."""
-        raise NotImplementedError("Subclasses must override this method.")
-
     def exists(self, path):
         """Test whether a path exists.  Returns False for broken symbolic links
         if the storage backend supports them.
@@ -121,14 +119,18 @@ class BaseStorageBackend(metaclass=abc.ABCMeta):
         """
         raise NotImplementedError("Subclasses must override this method.")
 
-    def pull(self, path, dst=None):
+    def pull(self, path, dst=None, decryptor=None):
         """Pulls a file from the given `path` in the storage backend to local
         filepath `dst`. If `dst` is ``None``, then a temporary filepath is
         generated.
         """
         if dst is None:
             _, dst = tempfile.mkstemp()
-        return self.download(path, dst)
+        return self.download(path, dst, decryptor)
+
+    def push(self, src, path, encryptor=None):
+        """Copies local absolute path `src` to remote `path`."""
+        raise NotImplementedError("Subclasses must override this method.")
 
     def storage_path(self, *components):
         """Returns the absolute path in the storage of `path`."""
