@@ -13,7 +13,7 @@ class LocalDiskBackend(BaseStorageBackend):
     """A storage backend that uses the local filesystem."""
     kind = 'local'
 
-    async def async_download(self, path, dst):
+    async def async_download(self, path, dst, decryptor=None):
         """This method exists only for API compatibility."""
         src = self.storage_path(path)
         async with AIOFile(src, 'rb') as sf:
@@ -24,7 +24,13 @@ class LocalDiskBackend(BaseStorageBackend):
                     await writer(chunk)
         return dst
 
-    async def async_push(self, src, path):
+    async def async_exists(self, path):
+        """Test whether a path exists.  Returns False for broken symbolic links
+        if the storage backend supports them.
+        """
+        return os.path.exists(self.storage_path(path))
+
+    async def async_push(self, src, path, encryptor=None):
         """Copies local absolute path `src` to remote `path`."""
         dst = self.storage_path(path)
         if not os.path.exists(os.path.dirname(dst)):
@@ -43,7 +49,7 @@ class LocalDiskBackend(BaseStorageBackend):
         """
         handler.fd.close()
 
-    def download(self, path, dst):
+    def download(self, path, dst, decryptor):
         """This method exists only for API compatibility."""
         shutil.copy2(self.storage_path(path), dst)
         return dst
@@ -54,12 +60,6 @@ class LocalDiskBackend(BaseStorageBackend):
         """
         return os.path.exists(self.storage_path(path))
 
-    async def async_exists(self, path):
-        """Test whether a path exists.  Returns False for broken symbolic links
-        if the storage backend supports them.
-        """
-        return os.path.exists(self.storage_path(path))
-
     def get_local_fd(self, handler):
         """Opens a local file descriptor."""
         local_path = self.storage_path(handler.path)
@@ -82,7 +82,7 @@ class LocalDiskBackend(BaseStorageBackend):
         """
         return handler.fd.read(size)
 
-    def push(self, src, path):
+    def push(self, src, path, encryptor=None):
         """Copies local absolute path `src` to remote `path`."""
         dst = self.storage_path(path)
         if not os.path.exists(os.path.dirname(dst)):
