@@ -14,6 +14,18 @@ class LocalDiskBackendTestCase(unittest.TestCase):
     backend_class = LocalDiskBackend
     capabilities = ['unlink']
 
+    @classmethod
+    def setUpClass(cls):
+        try:
+            cls.loop = asyncio.get_event_loop()
+        except RuntimeError:
+            cls.loop = asyncio.new_event_loop()
+            asyncio.set_event_loop(cls.loop)
+
+    @classmethod
+    def tearDownClass(cls):
+        cls.loop.close()
+
     def setUp(self):
         self.backend = self.get_backend()
 
@@ -161,7 +173,9 @@ class LocalDiskBackendTestCase(unittest.TestCase):
         src = 'foo/bar/baz/taz'
         async def afunc():
             async with self.backend.async_open(src, 'w') as f:
+                self.assertFalse(f.is_dirty())
                 await f.write("Hello world!")
+                self.assertTrue(f.is_dirty())
             self.assertTrue(await self.backend.async_exists(src))
 
         asyncio.run(afunc())
